summaryrefslogtreecommitdiffstats
path: root/kbackgammon/engines/nextgen/kbgng.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbackgammon/engines/nextgen/kbgng.h')
-rw-r--r--kbackgammon/engines/nextgen/kbgng.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kbackgammon/engines/nextgen/kbgng.h b/kbackgammon/engines/nextgen/kbgng.h
index 99ea82c1..12c94140 100644
--- a/kbackgammon/engines/nextgen/kbgng.h
+++ b/kbackgammon/engines/nextgen/kbgng.h
@@ -51,13 +51,14 @@
class KBgEngineNg : public KBgEngine
{
Q_OBJECT
+ TQ_OBJECT
public:
/*
* Constructor and destructor
*/
- KBgEngineNg( TQWidget *parent = 0, TQString *name = 0, TQPopupMenu *pmenu = 0);
+ KBgEngineNg( TQWidget *tqparent = 0, TQString *name = 0, TQPopupMenu *pmenu = 0);
virtual ~KBgEngineNg();
/**
@@ -152,11 +153,11 @@ public slots:
void slotPlayerJoinedGame(KPlayer *p);
- void slotNetworkData(int msgid, const TQByteArray &msg, Q_UINT32 receiver, Q_UINT32 sender);
+ void slotNetworkData(int msgid, const TQByteArray &msg, TQ_UINT32 receiver, TQ_UINT32 sender);
void slotCreatePlayer(KPlayer *&, int, int, bool, KGame *);
- void slotClientDisconnected(Q_UINT32, bool);
- void slotClientConnected(Q_UINT32);
+ void slotClientDisconnected(TQ_UINT32, bool);
+ void slotClientConnected(TQ_UINT32);
void slotPropertyChanged(KGamePropertyBase *p, KGame *me);
void slotPropertyChanged(KGamePropertyBase *p, KPlayer *me);
@@ -220,7 +221,7 @@ private:
int _nplayers;
TQString _host;
- Q_UINT16 _port;
+ TQ_UINT16 _port;
// ************************************************************
// ************************************************************
@@ -244,11 +245,11 @@ private:
/**
* Create the i-th player. Legal values for i are 0 and 1. The
* name of the player is taken from @ref _name and the parent of
* the player is @ref _player. That means that the players are
* automatically deleted.
*/
- KBgPlayer * createPlayer(int i, TQString name = TQString::null);
+ KBgPlayer * createPlayer(int i, TQString name = TQString());
private:
@@ -244,11 +245,11 @@ private:
/**
* Create the i-th player. Legal values for i are 0 and 1. The
- * name of the player is taken from @ref _name and the parent of
+ * name of the player is taken from @ref _name and the tqparent of
* the player is @ref _player. That means that the players are
* automatically deleted.